@@ -25,14 +25,12 @@
 ;;; Code:
 
 (require 'magithub-core)
-(require 'magithub-cache)
 
 (defun magithub-orgs-list ()
   "List organizations for the currently authenticated user."
   (magithub-cache :user-demographics
     `(progn ,(ghub--username)
-            (ghubp-get-user-orgs))
-    :context nil))
+            (ghubp-get-user-orgs))))
 
 (provide 'magithub-orgs)
 ;;; magithub-orgs.el ends here
