@@ -7,6 +7,11 @@
 ;;; Code:
 
 (require 'ert)
+(require 'magithub-core)
+(require 'ghub+)
+
+(setq ghubp-request-override-function
+      #'magithub-mock-ghub-request)
 
 (defmacro magithub-test-cache-with-new-cache (plist &rest body)
   (declare (indent 1))
@@ -14,7 +19,6 @@
          (magithub-cache--cache (make-hash-table)))
      ,@body))
 
-(require 'magithub-cache)
 (ert-deftest magithub-test-cache ()
   (magithub-test-cache-with-new-cache ((:test . 30))
     (should (equal t (magithub-cache :test t)))))
@@ -24,18 +28,21 @@
   (let ((repo '((owner (login . "vermiculus"))
                 (name . "magithub"))))
     (should (equal repo (magithub--url->repo "git@github.com:vermiculus/magithub.git")))
-    (should (equal repo (magithub--url->repo "git@github.com:vermiculus/magithub")))))
+    (should (equal repo (magithub--url->repo "git@github.com:vermiculus/magithub")))
+    (should (equal repo (magithub--url->repo "git+ssh://github.com/vermiculus/magithub")))
+    (should (equal repo (magithub--url->repo "ssh://git@github.com/vermiculus/magithub")))))
 
 (ert-deftest magithub-test-source-repo ()
   "Test basic API functionality.
 This tests everything from checking API availability to
 determining that we're in a GitHub repository to actually making
 cached API calls."
-  (should (magithub-source--sparse-repo))
-  (should (magithub-source-repo))
-  (should (let ((magithub-cache nil)) ; force API call
-            (magithub-source-repo)))
-  (should (let ((magithub-cache t))   ; force cache read
-            (magithub-source-repo))))
+  (let ((magithub--api-last-checked (current-time)))
+    (should (magithub-source--sparse-repo))
+    (should (magithub-repo))
+    (should (let ((magithub-cache t))     ; force API call
+              (magithub-repo)))
+    (should (let ((magithub-cache nil))   ; force cache read
+              (magithub-repo)))))
 
 ;;; magithub-test.el ends here
